@@ -1,11 +1,11 @@
 package Dist::Zilla::PluginBundle::TAPPER;
-# git description: v0.001-4-g1e5dc57
+# git description: v0.002-2-gf537675
 
 BEGIN {
   $Dist::Zilla::PluginBundle::TAPPER::AUTHORITY = 'cpan:TAPPER';
 }
 # ABSTRACT: Build your distributions like TAPPER does
-$Dist::Zilla::PluginBundle::TAPPER::VERSION = '0.002';
+$Dist::Zilla::PluginBundle::TAPPER::VERSION = '0.003';
 use Moose 1.00;
 use Method::Signatures::Simple;
 use Moose::Util::TypeConstraints;
@@ -130,6 +130,16 @@ has homepage_url => (
     },
 );
 
+has skip_pod_modules => (
+    is      => 'ro',
+    isa     => Str,
+    lazy    => 1,
+    default => '',
+    handles => {
+        skip => 'as_string',
+    },
+);
+
 method _build_homepage_url {
     return sprintf $self->_cpansearch_pattern, $self->dist;
 }
@@ -329,7 +339,10 @@ method configure {
     $self->add_plugins('Test::NoTabs')
         unless $self->disable_tab_tests;
 
-    $self->add_plugins('PodCoverageTests')
+    $self->add_plugins(
+        ['Test::Pod::Coverage::Configurable' => {
+            'skip'          => $self->skip_pod_modules,
+         }])
         unless $self->disable_pod_coverage_tests;
 
     $self->add_plugins(
